/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-07-22 14:29:15
 * @LastEditTime: 2022-10-28 14:50:34
 * @LastEditors: ldh
 * @Version: 1.0.0
 * @Description: 调解力量
 */
import React, { useState, useEffect } from 'react';
import { Col, Row, Typography } from 'antd';
import { mediator1, mediator2, mediationUnit } from '../../../assets/images/icon';
import * as $$ from '../../../utils/utility';

const { Text } = Typography;

// 获取调解力量
function getDataApi(caseId) {
	return $$.ax.request({ url: 'caseInfo/getMediatePower?caseId=' + caseId, type: 'get', service: 'mediate' });
}

const MediationPower = ({ caseId }) => {
	const [data, setData] = useState({});

	useEffect(() => {
		async function getData() {
			global.setSpinning(true);
			const res = await getDataApi(caseId);
			global.setSpinning(false);
			if (res.type) {
				setData(res.data);
			}
		}
		getData();
	}, [caseId]);

	return (
		<div className="mediationPower">
			<Row gutter={[16, 12]}>
				<Col span={24}>
					<h5>调解组织</h5>
				</Col>
				<Col span={24}>
					<Row gutter={[16, 12]}>
						<Col span={8}>
							<div className="public-fileCard public-fileCard-noBorder2">
								<img src={mediationUnit} alt="" />
								<div className="public-fileCard-main">
									<Text>{data.mediateUnit?.name}</Text>
									<div className="public-fileCard-action">签收时间：{$$.timeFormat(data.mediateUnit?.signTime)}</div>
								</div>
							</div>
						</Col>
					</Row>
				</Col>
				<Col span={24}>
					<div className="caseDetail-divider" />
				</Col>
				<Col span={24}>
					<h5>调解员</h5>
				</Col>
				<Col span={24}>
					<Row gutter={[16, 12]}>
						{data.mediator?.name ? (
							<Col span={8}>
								<div className="public-fileCard public-fileCard-noBorder2">
									<img src={mediator1} alt="" />
									<div className="public-fileCard-main">
										<Text>{data.mediator?.name}</Text>
										<div className="public-fileCard-action">
											<div>调解开始时间：{$$.timeFormat(data.mediator?.mediStartTime)}</div>
											<div>调解结束时间：{$$.timeFormat(data.mediator?.mediEndTime)}</div>
										</div>
									</div>
								</div>
							</Col>
						) : (
							<Col span={24}>{$$.MyEmpty()}</Col>
						)}
					</Row>
				</Col>
				<Col span={24}>
					<div className="caseDetail-divider" />
				</Col>
				<Col span={24}>
					<h5>协助调解员</h5>
				</Col>
				<Col span={24}>
					<Row gutter={[16, 12]}>
						{data.assistMediators?.map((x, t) => (
							<Col span={8} key={t}>
								<div className="public-fileCard public-fileCard-noBorder2">
									<img src={mediator2} alt="" />
									<div className="public-fileCard-main">
										<Text>{x.assUserName}</Text>
										<div className="public-fileCard-action">
											<div>参与协助时间：{$$.timeFormat(x.createTime)}</div>
											{/* <div>反馈结果时间：{$$.timeFormat(x.resultTime)}</div> */}
										</div>
									</div>
								</div>
							</Col>
						))}
						{!data.assistMediators?.length && <Col span={24}>{$$.MyEmpty()}</Col>}
					</Row>
				</Col>
			</Row>
		</div>
	);
};

export default MediationPower;
